/*
    VLDocking Framework 2.1
    Copyright VLSOLUTIONS, 2004-2006

    email : info@vlsolutions.com
------------------------------------------------------------------------
This software is distributed under the CeCILL license, a GNU GPL-compatible
license adapted to french law.
French and English license headers are provided at the begining of
the source files of this software application.
------------------------------------------------------------------------
LICENCE CeCILL (FRENCH VERSION).
------------------------------------------------------------------------
Ce logiciel est un programme informatique servant  amliorer les interfaces
homme-machine d'applications Java bases sur Swing, en leur apportant un
ensemble de fonctions relatives au dockage des composants.

Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilit au code source et des droits de copie,
de modification et de redistribution accords par cette licence, il n'est
offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,
seule une responsabilit restreinte pse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concdants successifs.

A cet gard  l'attention de l'utilisateur est attire sur les risques
associs au chargement,   l'utilisation,   la modification et/ou au
dveloppement et  la reproduction du logiciel par l'utilisateur tant
donn sa spcificit de logiciel libre, qui peut le rendre complexe 
manipuler et qui le rserve donc  des dveloppeurs et des professionnels
avertis possdant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invits  charger  et  tester  l'adquation  du
logiciel  leurs besoins dans des conditions permettant d'assurer la
scurit de leurs systmes et ou de leurs donnes et, plus gnralement,
 l'utiliser et l'exploiter dans les mmes conditions de scurit.

Le fait que vous puissiez accder  cet en-tte signifie que vous avez
pris connaissance de la licence CeCILL, et que vous en avez accept les
termes.

------------------------------------------------------------------------
CeCILL License (ENGLISH VERSION)
------------------------------------------------------------------------

This software is a computer program whose purpose is to enhance Human-Computer
Interfaces written in Java with the Swing framework, providing them a set of
functions related to component docking.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

*/


package com.vlsolutions.swing.docking;

import java.awt.Component;

/** Describes a Dockable that can contain sub-dockables.
 * <p>
 * This class allows dockable nesting, with full support for workspace save and restore.
 * <p> 
 * Currently this class is associated to a CompoundDockingPanel component : you 
 * insert dockables into it with an initial addDockable(CompoundDockable) invocation from DockingDesktop, 
 * and further dockables with split/createTab calls.
 * <p>
 * Example :
 * <pre>
 *   DockingDesktop desk = ...
 *   desk.addDockable(dockable1);
 *   desk.split(dockable1, dockable2, DockingConstants.SPLIT_RIGHT);
 *   // now let's add a compound dockable
 *   CompoundDockable compound = new CompoundDockable(new DockKey("Compound!"));
 *   desk.split(dockable1, compound);
 *   // and add a tab into it
 *   desk.addDockable(compound, dockable3); // initial nesting : new API call
 *   desk.createTab(dockable3, dockable4, 1); // a tab, using standard API
 * </pre>
 * <p>
 * CompoundDockables are displayed as SingleDockableContainers (with a title bar). Don't 
 * forget to properly initialize the DockKey of this dockable to have it well presented on 
 * screen (name, tooltip, icon).
 *
 * @author Lilian Chamontin, VLSolutions
 * @since 2.1
 */
public class CompoundDockable implements Dockable {

  private CompoundDockingPanel panel = new CompoundDockingPanel(this);

  private DockKey key;
  
  /** Constructs a new CompoundDockable with a given key */
  public CompoundDockable(DockKey key){
    this.key = key;
  }
  
  /** Returns the key used to describe this dockable */
  public DockKey getDockKey() {
    return key;
  }

  /** Returns the component used by this dockable.
   *
   * <p> 
   * Implementation note : this method always returns a CompoundDockingPanel.
   * 
   */
  public final Component getComponent() {
    return panel;
  }
  
}
