/*
    VLDocking Framework 2.1
    Copyright VLSOLUTIONS, 2004-2006

    email : info@vlsolutions.com
------------------------------------------------------------------------
This software is distributed under the CeCILL license, a GNU GPL-compatible
license adapted to french law.
French and English license headers are provided at the begining of
the source files of this software application.
------------------------------------------------------------------------
LICENCE CeCILL (FRENCH VERSION).
------------------------------------------------------------------------
Ce logiciel est un programme informatique servant  amliorer les interfaces
homme-machine d'applications Java bases sur Swing, en leur apportant un
ensemble de fonctions relatives au dockage des composants.

Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilit au code source et des droits de copie,
de modification et de redistribution accords par cette licence, il n'est
offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,
seule une responsabilit restreinte pse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concdants successifs.

A cet gard  l'attention de l'utilisateur est attire sur les risques
associs au chargement,   l'utilisation,   la modification et/ou au
dveloppement et  la reproduction du logiciel par l'utilisateur tant
donn sa spcificit de logiciel libre, qui peut le rendre complexe 
manipuler et qui le rserve donc  des dveloppeurs et des professionnels
avertis possdant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invits  charger  et  tester  l'adquation  du
logiciel  leurs besoins dans des conditions permettant d'assurer la
scurit de leurs systmes et ou de leurs donnes et, plus gnralement,
 l'utiliser et l'exploiter dans les mmes conditions de scurit.

Le fait que vous puissiez accder  cet en-tte signifie que vous avez
pris connaissance de la licence CeCILL, et que vous en avez accept les
termes.

------------------------------------------------------------------------
CeCILL License (ENGLISH VERSION)
------------------------------------------------------------------------

This software is a computer program whose purpose is to enhance Human-Computer
Interfaces written in Java with the Swing framework, providing them a set of
functions related to component docking.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

*/


package com.vlsolutions.swing.docking;

import java.awt.Dialog;
import java.awt.Frame;
import java.awt.Window;

/** Default implementation of the DockableContainerFactory.
 * <p>
 * Uses <code>DockView</code> as a <code>SingleDockableContainer</code>,
 * and <code>DockTabbedPane</code> as a <code>TabbedDockableContainer</code>
 * <p>
 * Note : the API has changed between VLDocking 1.1 and 2.0 : the createDockableContainer
 * now uses a second parameter to specify the context of the container creation.
 *
 * @author Lilian Chamontin, vlsolutions.
 * @version 2.0
 */

public class DefaultDockableContainerFactory extends DockableContainerFactory {
  
  
  public DefaultDockableContainerFactory() {
  }
  
  /** Returns the component used to modify the expand panel size when expanded from the top.
   * This implementation uses the following components :
   *<ul>
   * <li> DockView for standard dockables
   * <li> TabbedDockView for dockable contained in a tabContainer
   * <li> MaximizedDockView for maximized dockables
   * <li> DetachedDockView for floating dockables.
   *</ul>
   *
   *@see DockView
   *@see TabbedDockView
   *@see MaximizedDockView
   *@see DetachedDockView
   */
  public SingleDockableContainer createDockableContainer(Dockable dockable, int parentType) {
    switch (parentType){
      case PARENT_TABBED_CONTAINER:
        return new TabbedDockView(dockable);
      case PARENT_DESKTOP:
        return new MaximizedDockView(dockable);
      case PARENT_SPLIT_CONTAINER:
        return new DockView(dockable);
      case PARENT_DETACHED_WINDOW:
        return new DetachedDockView(dockable);
      default :
        throw new RuntimeException("Wrong dockable container type");
    }    
  }
  
  /** Returns the container used for tabbed docking.
   *<p>
   * Current implementation uses the DockTabbedPane class.
   *
   * @see DockTabbedPane
   */
  public TabbedDockableContainer createTabbedDockableContainer() {
    return new DockTabbedPane();
  }
  
  
  /** This method is called when a dockable is detached from the DockingDesktop and put
   * in the FLOATING state.
   *<p>
   * The floating container must be an instanceof Dialog or Window.
   */
  public FloatingDockableContainer createFloatingDockableContainer(Window owner){
    if (owner instanceof Dialog){
      return new FloatingDialog((Dialog)owner);
    } else {
      return new FloatingDialog((Frame)owner);
    }
  }
  
  /** This implementation of the factory method return a default DockViewTitleBar 
   *  object.
   *@since 2.1.3
   */
  public DockViewTitleBar createTitleBar() {
    return new DockViewTitleBar();
  }
  
  
  
}
